@@ -197,9 +197,11 @@ Gunnar Wolf <gwolf@gwolf.org>
 
 =head1 COPYRIGHT
 
-Copyright 2005 Gunnar Wolf / Instituto de Investigaciones Econmicas UNAM
-This module is Free Software, it can be redistributed under the same terms
-as Perl.
+Copyright 2005-2008 Gunnar Wolf / Instituto de Investigaciones
+Econmicas UNAM 
+
+This module is Free Software; it can be redistributed under the same
+terms as Perl.
 
 =cut
 
